@@ -6,12 +6,12 @@ use std::{
 
 use bstr::{BStr, ByteSlice};
 
-use crate::{FullName, PartialName};
+use crate::{FullNameRef, PartialNameRef};
 
-/// The error used in the [`PartialName`][super::PartialName]::try_from(…) implementations.
+/// The error used in the [`PartialNameRef`][super::PartialNameRef]::try_from(…) implementations.
 pub type Error = git_validate::reference::name::Error;
 
-impl<'a> FullName<'a> {
+impl<'a> FullNameRef<'a> {
     /// Convert this name into the relative path identifying the reference location.
     pub fn to_path(self) -> Cow<'a, Path> {
         self.0.to_path().expect("UTF-8 conversion always succeeds").into()
@@ -23,7 +23,7 @@ impl<'a> FullName<'a> {
     }
 }
 
-impl<'a> PartialName<'a> {
+impl<'a> PartialNameRef<'a> {
     /// Convert this name into the relative path possibly identifying the reference location.
     /// Note that it may be only a partial path though.
     pub fn to_partial_path(self) -> Cow<'a, Path> {
@@ -36,62 +36,62 @@ impl<'a> PartialName<'a> {
     }
 }
 
-impl<'a> TryFrom<&'a BStr> for FullName<'a> {
+impl<'a> TryFrom<&'a BStr> for FullNameRef<'a> {
     type Error = Error;
 
     fn try_from(v: &'a BStr) -> Result<Self, Self::Error> {
-        Ok(FullName(git_validate::reference::name(v)?))
+        Ok(FullNameRef(git_validate::reference::name(v)?))
     }
 }
 
-impl<'a> TryFrom<FullName<'a>> for PartialName<'a> {
+impl<'a> TryFrom<FullNameRef<'a>> for PartialNameRef<'a> {
     type Error = Infallible;
 
-    fn try_from(v: FullName<'a>) -> Result<Self, Self::Error> {
-        Ok(PartialName(v.0))
+    fn try_from(v: FullNameRef<'a>) -> Result<Self, Self::Error> {
+        Ok(PartialNameRef(v.0))
     }
 }
 
-impl<'a> TryFrom<&'a BStr> for PartialName<'a> {
+impl<'a> TryFrom<&'a BStr> for PartialNameRef<'a> {
     type Error = Error;
 
     fn try_from(v: &'a BStr) -> Result<Self, Self::Error> {
-        Ok(PartialName(git_validate::reference::name_partial(v)?))
+        Ok(PartialNameRef(git_validate::reference::name_partial(v)?))
     }
 }
 
-impl<'a> TryFrom<&'a str> for FullName<'a> {
+impl<'a> TryFrom<&'a str> for FullNameRef<'a> {
     type Error = Error;
 
     fn try_from(v: &'a str) -> Result<Self, Self::Error> {
         let v = v.as_bytes().as_bstr();
-        Ok(FullName(git_validate::reference::name(v)?))
+        Ok(FullNameRef(git_validate::reference::name(v)?))
     }
 }
 
-impl<'a> TryFrom<&'a str> for PartialName<'a> {
+impl<'a> TryFrom<&'a str> for PartialNameRef<'a> {
     type Error = Error;
 
     fn try_from(v: &'a str) -> Result<Self, Self::Error> {
         let v = v.as_bytes().as_bstr();
-        Ok(PartialName(git_validate::reference::name_partial(v)?))
+        Ok(PartialNameRef(git_validate::reference::name_partial(v)?))
     }
 }
 
-impl<'a> TryFrom<&'a String> for FullName<'a> {
+impl<'a> TryFrom<&'a String> for FullNameRef<'a> {
     type Error = Error;
 
     fn try_from(v: &'a String) -> Result<Self, Self::Error> {
         let v = v.as_bytes().as_bstr();
-        Ok(FullName(git_validate::reference::name(v)?))
+        Ok(FullNameRef(git_validate::reference::name(v)?))
     }
 }
 
-impl<'a> TryFrom<&'a String> for PartialName<'a> {
+impl<'a> TryFrom<&'a String> for PartialNameRef<'a> {
     type Error = Error;
 
     fn try_from(v: &'a String) -> Result<Self, Self::Error> {
         let v = v.as_bytes().as_bstr();
-        Ok(PartialName(git_validate::reference::name_partial(v)?))
+        Ok(PartialNameRef(git_validate::reference::name_partial(v)?))
     }
 }
