@@ -2,7 +2,7 @@ use std::{borrow::Cow, convert::TryInto, path::Path};
 
 use bstr::{BStr, BString, ByteSlice, ByteVec};
 
-use crate::{Namespace, PartialName};
+use crate::{Namespace, PartialNameRef};
 
 impl Namespace {
     /// Dissolve ourselves into the interior representation
@@ -24,7 +24,7 @@ impl Namespace {
 /// For more information, consult the [git namespace documentation](https://git-scm.com/docs/gitnamespaces).
 pub fn expand<'a, Name, E>(namespace: Name) -> Result<Namespace, git_validate::refname::Error>
 where
-    Name: TryInto<PartialName<'a>, Error = E>,
+    Name: TryInto<PartialNameRef<'a>, Error = E>,
     git_validate::refname::Error: From<E>,
 {
     let namespace = namespace.try_into()?.0;
