@@ -9,12 +9,11 @@ pub use error::Error;
 
 use crate::{
     file,
-    mutable::FullName,
     store::{
         file::{loose, path_to_name},
         packed,
     },
-    PartialName,
+    FullName, PartialNameRef,
 };
 
 enum Transform {
@@ -25,7 +24,7 @@ enum Transform {
 impl file::Store {
     /// Find a single reference by the given `path` which is required to be a valid reference name.
     ///
-    /// If `packed` is provided, the reference search will extend to the packed buffer created with [`packed()`][file::Store::packed()].
+    /// If `packed` is provided, the reference search will extend to the packed buffer created with [`packed()`][file::Store::packed_buffer()].
     /// Note that the caller is responsible for its freshness, i.e. assuring it wasn't modified since it was read.
     ///
     /// Returns `Ok(None)` if no such ref exists.
@@ -35,13 +34,13 @@ impl file::Store {
     /// The lookup algorithm follows the one in [the git documentation][git-lookup-docs].
     ///
     /// [git-lookup-docs]: https://github.com/git/git/blob/5d5b1473453400224ebb126bf3947e0a3276bdf5/Documentation/revisions.txt#L34-L46
-    pub fn find<'a, 'p, 's, Name, E>(
+    pub fn try_find<'a, 'p, 's, Name, E>(
         &'s self,
         partial: Name,
         packed: Option<&'p packed::Buffer>,
     ) -> Result<Option<file::Reference<'p>>, Error>
     where
-        Name: TryInto<PartialName<'a>, Error = E>,
+        Name: TryInto<PartialNameRef<'a>, Error = E>,
         Error: From<E>,
     {
         let path = partial.try_into()?;
@@ -49,12 +48,16 @@ impl file::Store {
     }
 
     /// Similar to [`file::Store::find()`] but a non-existing ref is treated as error.
-    pub fn loose_find<'a, Name, E>(&self, partial: Name) -> Result<Option<loose::Reference>, Error>
+    ///
+    /// Find only loose references, that is references that aren't in the packed-refs buffer.
+    /// All symbolic references are loose references.
+    /// `HEAD` is always a loose reference.
+    pub fn try_find_loose<'a, Name, E>(&self, partial: Name) -> Result<Option<loose::Reference>, Error>
     where
-        Name: TryInto<PartialName<'a>, Error = E>,
+        Name: TryInto<PartialNameRef<'a>, Error = E>,
         Error: From<E>,
     {
-        self.find(partial, None)
+        self.try_find(partial, None)
             .map(|r| r.map(|r| r.try_into().expect("only loose refs are found without pack")))
     }
 
@@ -116,8 +119,8 @@ impl file::Store {
                 if is_definitely_absolute {
                     if let Some(packed) = packed {
                         let full_name = path_to_name(relative_path);
-                        let full_name = PartialName((*full_name).as_bstr());
-                        if let Some(packed_ref) = packed.find(full_name)? {
+                        let full_name = PartialNameRef((*full_name).as_bstr());
+                        if let Some(packed_ref) = packed.try_find(full_name)? {
                             return Ok(Some(file::Reference::Packed(packed_ref)));
                         };
                     }
@@ -173,18 +176,18 @@ pub mod existing {
             file::{find, loose},
             packed,
         },
-        PartialName,
+        PartialNameRef,
     };
 
     impl file::Store {
-        /// Similar to [`file::Store::find_existing()`] but a non-existing ref is treated as error.
-        pub fn find_existing<'a, 'p, 's, Name, E>(
+        /// Similar to [`file::Store::find()`] but a non-existing ref is treated as error.
+        pub fn find<'a, 'p, 's, Name, E>(
             &'s self,
             partial: Name,
             packed: Option<&'p packed::Buffer>,
         ) -> Result<file::Reference<'p>, Error>
         where
-            Name: TryInto<PartialName<'a>, Error = E>,
+            Name: TryInto<PartialNameRef<'a>, Error = E>,
             crate::name::Error: From<E>,
         {
             let path = partial
@@ -198,12 +201,12 @@ pub mod existing {
         }
 
         /// Similar to [`file::Store::find()`] won't handle packed-refs.
-        pub fn loose_find_existing<'a, Name, E>(&self, partial: Name) -> Result<loose::Reference, Error>
+        pub fn find_loose<'a, Name, E>(&self, partial: Name) -> Result<loose::Reference, Error>
         where
-            Name: TryInto<PartialName<'a>, Error = E>,
+            Name: TryInto<PartialNameRef<'a>, Error = E>,
             crate::name::Error: From<E>,
         {
-            self.find_existing(partial, None)
+            self.find(partial, None)
                 .map(|r| r.try_into().expect("always loose without packed"))
         }
     }
