@@ -8,8 +8,8 @@ use git_features::fs::walkdir::DirEntryIter;
 use os_str_bytes::OsStrBytes;
 
 use crate::{
-    mutable::FullName,
     store::file::{self, loose::Reference},
+    FullName,
 };
 
 /// An iterator over all valid loose reference paths as seen from a particular base directory.
@@ -113,7 +113,7 @@ impl file::Store {
     ///
     /// Reference files that do not constitute valid names will be silently ignored.
     ///
-    /// See [`Store::packed()`][file::Store::packed()] for interacting with packed references.
+    /// See [`Store::packed()`][file::Store::packed_buffer()] for interacting with packed references.
     pub fn loose_iter(&self) -> std::io::Result<Loose> {
         let refs = self.refs_dir();
         if !refs.is_dir() {
