@@ -7,7 +7,7 @@ mod reference {
     use super::Result;
     use crate::{
         store::{packed, packed::decode},
-        FullName,
+        FullNameRef,
     };
 
     #[test]
@@ -28,7 +28,7 @@ mod reference {
         assert_eq!(
             parsed,
             packed::Reference {
-                name: FullName("refs/heads/alternates-after-packs-and-loose".into()),
+                name: FullNameRef("refs/heads/alternates-after-packs-and-loose".into()),
                 target: "d53c4b0f91f1b29769c9430f2d1c0bcab1170c75".into(),
                 object: Some("e9cdc958e7ce2290e2d7958cdb5aa9323ef35d37".into())
             }
@@ -38,7 +38,7 @@ mod reference {
 
         let (input, parsed) = decode::reference::<VerboseError<_>>(input)?;
         assert!(input.is_empty(), "exhausted");
-        assert_eq!(parsed.name, FullName("refs/heads/avoid-double-lookup".into()));
+        assert_eq!(parsed.name, FullNameRef("refs/heads/avoid-double-lookup".into()));
         assert_eq!(parsed.target, "eaae9c1bc723209d793eb93f5587fa2604d5cd92");
         assert!(parsed.object.is_none());
         Ok(())
